@@ -5,16 +5,20 @@ Uncertainty Quantification with Python
 
 import pkg_resources
 
-import UQpy.DimensionReduction
 import UQpy.Distributions
+import UQpy.SampleMethods
+import UQpy.DimensionReduction
 import UQpy.Inference
 import UQpy.Reliability
 import UQpy.RunModel
 import UQpy.SampleMethods
 import UQpy.StochasticProcess
 import UQpy.Surrogates
+import UQpy.Sensitivity
 import UQpy.Transformations
 import UQpy.Utilities
+
+
 from UQpy.DimensionReduction import *
 from UQpy.Distributions import *
 from UQpy.Inference import *
@@ -25,6 +29,7 @@ from UQpy.StochasticProcess import *
 from UQpy.Surrogates import *
 from UQpy.Transformations import *
 from UQpy.Utilities import *
+from UQpy.Sensitivity import *
 
 try:
     __version__ = pkg_resources.get_distribution("UQpy").version
